California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 038 - TAX FOR EARLY EDUCATION AND EARLY CHILDHOOD PROGRAMS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1350907 | GREENLINING ACTION FUND FOR YES ON PROPOSITION 33, WITH MAJOR FUNDING PROVIDED BY MERCURY INSURANCE CHAIRMAN GEORGE JOSEPH | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1352407 | COMMITTEE TO DEFEND PROP. 38, SPONSORED BY THE ADVANCEMENT PROJECT AND EDUCATION ADVOCATES, WITH FINANCIAL SUPPORT FROM MOLLY MUNGER AND STEPHEN ENGLISH | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1343629 | YES ON 38 - MORE MONEY FOR OUR LOCAL SCHOOLS, NOT SACRAMENTO. ENDORSED BY THE CA STATE PTA, SCHOOL DISTRICTS, EDUCATION ADVOCATES & THE ADVANCEMENT PROJECT, WITH FINANCIAL SUPPORT FROM MOLLY MUNGER | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1348560 | STOP THE MIDDLE-CLASS INCOME-TAX HIKE - NO ON PROP. 38, SPONSORED BY THE CALIFORNIA MEDICAL ASSOCIATION PHYSICIANS' ISSUES COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1318621 | CALIFORNIANS AGAINST HIGHER TAXES, A COALITION OF TAXPAYERS AND EMPLOYERS | OPPOSE